@@ -14,10 +14,6 @@ class Workspace():
         self._data = workspace_dict
         self._check_data()
         
-        
-
-    def __repr__(self):
-        return "<Workspace id={} name={}>".format(self.id, self.name)
 
     @property
     def id(): pass
@@ -82,4 +78,49 @@ class Workspace():
             
             
     def __len__(self):
-        len(self.collections)
\ No newline at end of file
+        len(self.collections)
+        
+
+    def __repr__(self):
+        return "<Workspace id={} name={}>".format(self.id, self.name)
+    
+    
+    
+class PublicWorkspace(Workspace):
+    ''' The public workspace is an edge case, and some information is not
+    available. '''
+    
+    def __init__(self, client):
+        super().__init__(client, {
+            'created' : 'N/A',
+            'creator_tenant_slug' : 'N/A',
+            'features' : [],
+            'id' : 'public',
+            'name' : 'public',
+            'roles' : [],
+            'storage_location' : 'AZ_North_Europe',
+            'subscription_level' : None,
+            'updated' : None
+        })
+        
+        
+        
+        
+        
+        
+        
+        
+        
+        
+        
+        
+        
+        
+        
+        
+        
+        
+        
+        
+        
+        
\ No newline at end of file
